@@ -1,6 +1,6 @@
 /* vim: ts=8:sw=4:expandtab
  *
- * $Id: DBIXS.h 13591 2009-11-24 13:07:10Z timbo $
+ * $Id: DBIXS.h 14297 2010-07-30 14:08:56Z timbo $
  *
  * Copyright (c) 1994-2009  Tim Bunce  Ireland
  *
@@ -15,8 +15,11 @@
 #define DBIS    dbis    /* default name for dbistate_t variable */
 #endif
 
-/* first pull in the standard Perl header files for extensions  */
+/* Here for backwards compat. PERL_POLLUTE was removed in perl 5.13.3 */
 #define PERL_POLLUTE
+#undef PERL_POLLUTE /* XXX temp undef to simplify testing */
+
+/* first pull in the standard Perl header files for extensions  */
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
@@ -39,16 +42,7 @@
 #include "dbi_sql.h"
 
 
-/* The DBIXS_VERSION value will be incremented whenever new code is
- * added to the interface (this file) or significant changes are made.
- * It's primary goal is to allow newer drivers to compile against an
- * older installed DBI. This is mainly an issue whilst the API grows
- * and learns from the needs of various drivers.  See also the
- * DBISTATE_VERSION macro below. You can think of DBIXS_VERSION as
- * being a compile time check and DBISTATE_VERSION as a runtime check.
- * By contract, DBIXS_REVISION is a driver source compatibility tool.
- */
-#define DBIXS_VERSION 93
+#define DBIXS_VERSION 93 /* superceeded by DBIXS_REVISION */
 
 #ifdef NEED_DBIXS_VERSION
 #if NEED_DBIXS_VERSION > DBIXS_VERSION
@@ -106,7 +100,7 @@ typedef struct dbih_com_std_st {
 
     I32  kids;          /* count of db's for dr's, st's for db's etc    */
     I32  active_kids;   /* kids which are currently DBIc_ACTIVE         */
-    U32 pad;            /* keep binary compat */
+    U32  pid;           /* pid of process that created handle */
     dbistate_t *dbistate;
 } dbih_com_std_t;
 
@@ -185,7 +179,7 @@ typedef struct {                /* -- FIELD DESCRIPTOR --               */
 } dbih_fdc_t;
 
 
-#define _imp2com(p,f)           ((p)->com.f)
+#define _imp2com(p,f)           ((p)->com.f) /* private */
 
 #define DBIc_FLAGS(imp)         _imp2com(imp, std.flags)
 #define DBIc_TYPE(imp)          _imp2com(imp, std.type)
@@ -271,10 +265,11 @@ typedef struct {                /* -- FIELD DESCRIPTOR --               */
 #define DBIcf_Executed    0x080000      /* do/execute called since commit/rollb */
 #define DBIcf_PrintWarn   0x100000      /* warn() on warning (err="0")          */
 #define DBIcf_Callbacks   0x200000      /* has Callbacks attribute hash         */
+#define DBIcf_AIADESTROY  0x400000      /* auto DBIcf_IADESTROY if pid changes  */
 /* NOTE: new flags may require clone() to be updated */
 
 #define DBIcf_INHERITMASK               /* what NOT to pass on to children */   \
-  (U32)( DBIcf_COMSET | DBIcf_IMPSET | DBIcf_ACTIVE | DBIcf_IADESTROY           \
+  (U32)( DBIcf_COMSET | DBIcf_IMPSET | DBIcf_ACTIVE | DBIcf_IADESTROY \
   | DBIcf_AutoCommit | DBIcf_BegunWork | DBIcf_Executed | DBIcf_Callbacks )
 
 /* general purpose bit setting and testing macros                       */
@@ -326,6 +321,10 @@ typedef struct {                /* -- FIELD DESCRIPTOR --               */
 #define DBIc_IADESTROY_on(imp)  (DBIc_FLAGS(imp) |=  DBIcf_IADESTROY)
 #define DBIc_IADESTROY_off(imp) (DBIc_FLAGS(imp) &= ~DBIcf_IADESTROY)
 
+#define DBIc_AIADESTROY(imp)     (DBIc_FLAGS(imp) &   DBIcf_AIADESTROY)
+#define DBIc_AIADESTROY_on(imp)  (DBIc_FLAGS(imp) |=  DBIcf_AIADESTROY)
+#define DBIc_AIADESTROY_off(imp) (DBIc_FLAGS(imp) &= ~DBIcf_AIADESTROY)
+
 #define DBIc_WARN(imp)          (DBIc_FLAGS(imp) &   DBIcf_WARN)
 #define DBIc_WARN_on(imp)       (DBIc_FLAGS(imp) |=  DBIcf_WARN)
 #define DBIc_WARN_off(imp)      (DBIc_FLAGS(imp) &= ~DBIcf_WARN)
@@ -396,7 +395,14 @@ typedef struct {                /* -- FIELD DESCRIPTOR --               */
 
 struct dbistate_st {
 
-#define DBISTATE_VERSION  95    /* Must change whenever dbistate_t does */
+/* DBISTATE_VERSION is checked at runtime via DBISTATE_INIT and check_version.
+ * It should be incremented on incompatible changes to dbistate_t structure.
+ * Additional function pointers being assigned from spare padding, where the
+ * size of the structure doesn't change, doesn't require an increment.
+ * Incrementing forces all XS drivers to need to be recompiled.
+ * (See also DBIXS_REVISION as a driver source compatibility tool.)
+ */
+#define DBISTATE_VERSION  94   /* ++ on incompatible dbistate_t changes */
 
     /* this must be the first member in structure                       */
     void (*check_version) _((const char *name,
